@@ -1,11 +1,12 @@
-use std::time::Duration;
-
-use jwtk::jwk::RemoteJwksVerifier;
-use serde::Deserialize;
-use serde_json::{Map, Value};
-
+#[cfg(feature = "remote-jwks")]
 #[tokio::main]
 async fn main() -> jwtk::Result<()> {
+    use std::time::Duration;
+
+    use jwtk::jwk::RemoteJwksVerifier;
+    use serde::Deserialize;
+    use serde_json::{Map, Value};
+
     #[derive(Deserialize)]
     struct Token {
         token: String,
@@ -23,7 +24,11 @@ async fn main() -> jwtk::Result<()> {
     );
     let c = j.verify::<Map<String, Value>>(&v.token).await?;
 
-    println!("{}", serde_json::to_string(c.claims())?);
+    println!("headers:\n{}", serde_json::to_string(c.header())?);
+    println!("claims:\n{}", serde_json::to_string(c.claims())?);
 
     Ok(())
 }
+
+#[cfg(not(feature = "remote-jwks"))]
+fn main() {}
